package modManager;

import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionListener;
import java.io.File;
import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.StandardCopyOption;

public class ModManagerUtils {
    public static void deleteDirectory(File directory) {
        File[] files = directory.listFiles();
        if (files != null) {
            for (File f : files) {
                if (f.isDirectory()) {
                    deleteDirectory(f);
                } else {
                    f.delete();
                }
            }
        }
        directory.delete();
    }

    public static void copyDirectory(Path source, Path target) throws IOException {
        Files.copy(source, target, StandardCopyOption.REPLACE_EXISTING);
        File[] files = source.toFile().listFiles();
        if (files != null) {
            for (File f : files) {
                if (f.isDirectory()) {
                    copyDirectory(f.toPath(), target.resolve(f.getName()));
                } else {
                    Files.copy(f.toPath(), target.resolve(f.getName()), StandardCopyOption.REPLACE_EXISTING);
                }
            }
        }
    }

    public static void showError(JFrame window, String message) {
        JOptionPane.showMessageDialog(window, message, "Error", JOptionPane.ERROR_MESSAGE);
    }

    public static JMenuItem createMenuItem(JMenu menu, String text, ActionListener listener) {
        JMenuItem item = new JMenuItem(text);
        item.addActionListener(listener);
        menu.add(item);
        return item;
    }

    public static JButton createButton(JPanel panel, String text, ActionListener listener) {
        JButton button = new JButton(text);
        button.addActionListener(listener);
        panel.add(button);
        return button;
    }

    public static File forceFileExtension(File file, String extension) {
        String filePath = file.getPath();
        int dotIndex = filePath.indexOf(".");
        if (dotIndex != -1) {
            filePath = filePath.substring(0, dotIndex);
        }
        return new File(filePath + extension);
    }

    public static boolean confirmReplace(Component parentComponent, File file) {
        if (file.exists()) {
            int option = JOptionPane.showConfirmDialog(parentComponent, file.getName() + " already exists. Do you want to replace it?",
                    "Replace file", JOptionPane.YES_NO_OPTION);
            return option == JOptionPane.YES_OPTION;
        }
        return true;
    }
}